============================================
DarkNet OpenSource Neural Networks in Python
============================================

.. image:: https://img.shields.io/github/workflow/status/zeroae/darknet.py/pypa-conda?label=pypa-conda&logo=github&style=flat-square
   :target: https://github.com/zeroae/darknet.py/actions?query=workflow%3Apypa-conda

.. image:: https://img.shields.io/conda/v/zeroae/darknet.py?logo=anaconda&style=flat-square
   :target: https://anaconda.org/zeroae/darknet.py


.. image:: https://img.shields.io/codecov/c/gh/zeroae/darknet.py?logo=codecov&style=flat-square
   :target: https://codecov.io/gh/zeroae/darknet.py

.. image:: https://img.shields.io/codacy/grade/CODACY_BADGE_TOKEN?logo=codacy&style=flat-square
   :target: https://www.codacy.com/app/zeroae/darknet.py
   :alt: Codacy Badge

.. image:: https://img.shields.io/badge/code--style-black-black?style=flat-square
   :target: https://github.com/psf/black


.. image:: https://img.shields.io/pypi/v/darknet.py?logo=pypi&style=flat-square
   :target: https://pypi.python.org/pypi/darknet.py

.. image:: https://readthedocs.org/projects/darknet.py/badge/?version=latest&style=flat-square
   :target: https://darknet.py.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status




DarkNet OpenSource Neural Networks in Python


* Free software: MIT
* Documentation: https://darknet.py.readthedocs.io.


Features
--------

* TODO


-------

This package was created with ght-render_ and the `sodre/ght-pypackage`_ project template.

.. _ght-render: https://github.com/sodre/action-ght-render
.. _`sodre/ght-pypackage`: https://github.com/sodre/ght-pypackage
